"use server";

import { ObjectId } from "mongodb";
import { getCollection } from "../mongodb";
import { ReactNode } from "react";

export type LinkType = {
    label: string;
    icon?: string;
    iconElement?: ReactNode;
    _id: string;
    href?: string;
    priority?: number;
    subCategory?: string[];
    location?: string;

}
export async function getLinkType(id: string) {
    const collection = await getCollection('link-type');
    return collection.findOne({ _id: new ObjectId(id) }).then(res => res ? {
        ...res,
        _id: res._id.toString()
    } as LinkType : null)
}
export async function getLinkTypeList({ page = 1, pageSize = 9999 }: {
    page?: number;
    pageSize?: number;
}) {
    const collection = await getCollection('link-type');
    const startIndex = (page - 1) * pageSize;
    const list = await collection.aggregate<LinkType>([
        { $sort: { priority: 1 } },
        { $skip: startIndex },
        { $limit: pageSize },
        {
            $addFields: {
                _id: { $toString: "$_id" }
            }
        }
    ]).toArray();

    // 计算总数量
    const total = await collection.countDocuments()
    return {
        total,
        list
    }
}